@@ -6,7 +6,7 @@ use vars qw($VERSION);
 use 5.006;    #perl 5.6.0
 use base qw(Class::Virtually::Abstract);
 
-$VERSION = '0.06';
+$VERSION = '0.07';
 
 __PACKAGE__->virtual_methods(qw(is_holiday holidays));
 
@@ -14,9 +14,19 @@ __PACKAGE__->virtual_methods(qw(is_holiday holidays));
 
 __END__
 
+=pod
+
+=begin markdown
+
+[![CPAN version](https://badge.fury.io/pl/Date-Holidays-Abstract.svg)](http://badge.fury.io/pl/Date-Holidays-Abstract)
+[![Build Status](https://travis-ci.org/jonasbn/Date-Holidays-Abstract.svg?branch=master)](https://travis-ci.org/jonasbn/Date-Holidays-Abstract)
+[![Coverage Status](https://coveralls.io/repos/jonasbn/Date-Holidays-Abstract/badge.png?branch=master)](https://coveralls.io/r/jonasbn/Date-Holidays-Abstract?branch=master)
+
+=end markdown
+
 =head1 NAME
 
-Date::Holidays::Abstract - abstract class for Date::Holidays::* modules
+Date::Holidays::Abstract - abstract class for Date::Holidays::* packages
 
 =head1 SYNOPSIS
 
@@ -33,7 +43,7 @@ Date::Holidays::Abstract - abstract class for Date::Holidays::* modules
 
 =head1 VERSION
 
-This POD describes version 0.05 of Date::Holidays::Abstract
+This POD describes version 0.07 of Date::Holidays::Abstract
 
 =head1 DESCRIPTION
 
@@ -138,8 +148,8 @@ configuration apart from what is mentioned in DEPENDENCIES
 
 =head1 DEPENDENCIES
 
-This class is subclassed from L<Class::Virtual>, but holds not direct
-dependencies apart from that class/module.
+This class is subclassed from L<Class::Virtually::Abstract>, but holds
+no direct dependencies apart from that class/module.
 
 =head1 INCOMPATIBILITIES
 
@@ -171,6 +181,8 @@ None known to the author
 
 =item * L<Class::Virtual>
 
+=item * L<Class::Virtually::Abstract>
+
 =back
 
 =head1 BUGS
@@ -195,7 +207,6 @@ Jonas B. Nielsen, (jonasbn) - C<< <jonasbn@cpan.org> >>
 
 Date-Holidays-Abstract is (C) by Jonas B. Nielsen, (jonasbn) 2004-2014
 
-Date-Holidays-Abstract is released under the Artistic License
-See: (http://www.perl.com/language/misc/Artistic.html) for details.
+Date-Holidays-Abstract is released under the Artistic License 2.0
 
 =cut
